@@ -22,7 +22,6 @@
 #include <QVector>
 
 #include "mathroutines.h"
-#include "options.h"
 #include "structs.h"
 
 int Ai::calcFrameIncrement[Options::EnumAiDifficulty::COUNT] = {15,8,6,2};
@@ -33,6 +32,7 @@ int Ai::calcNextShot[Options::EnumAiDifficulty::COUNT]       = {300,200,90,60};
 
 Ai::Ai(int pn,ShipSprite* s[2],QList<BulletSprite*>* b[2],
        QList<MineSprite*>* m[2],SConfig *c)
+ : random(QRandomGenerator::securelySeeded())
 {
    int i;
 
@@ -89,8 +89,8 @@ void Ai::newRound()
 
    calculateCollisions=(int)(calcCollisions[Options::aiDifficulty(playerNumber)]
                              /cfg->gamespeed);
-   waitShot=(int) rint( random.getDouble() *
-	          calcNextShot[Options::aiDifficulty(playerNumber)]
+   waitShot=(int) rint( random.bounded(1.0) *
+                 calcNextShot[Options::aiDifficulty(playerNumber)]
                   /cfg->gamespeed);
 
    qDeleteAll(myShots);
@@ -226,7 +226,7 @@ void Ai::calculateNextPositions()
       nextPositions(ship[i]->toAiSprite(),shipsNextPositions[i],
                     calcFrameIncrement[Options::aiDifficulty(playerNumber)]);
 
-   if(cfg->maxMines > aiMines[0]->size())
+   if(cfg->maxMines > static_cast<uint>(aiMines[0]->size()))
       for(i=0;i<2;++i)
          aiMines[i]->resize(cfg->maxMines);
 
@@ -261,7 +261,7 @@ void Ai::tryShots()
 
        //if too much bullets are on the playfield, no shot is tried
    if(bullets[playerNumber]->count() <
-      (cfg->maxBullets+ship[playerNumber]->getBulletPowerups()))
+      (static_cast<int>(cfg->maxBullets) + ship[playerNumber]->getBulletPowerups()))
    {
       for(f=0;f<=frameNum;++f)
       {
@@ -582,17 +582,16 @@ void Ai::shotScores()
 void Ai::chooseAction()
 {
    double bestScore=1e10;
-   Shot *bestShot=NULL,*s;
+   Shot *bestShot = nullptr,*s;
    AiSprite actualpos;
    double posangle,movephi,phiright,phileft,torotate=0,velangle;
    int framesleft,framesright;
    bool rotateAndAccelerate=false;
-   Hit *nextHit=0;
-   int shotHitTime;
+   Hit *nextHit = nullptr;
    int i;
 
-   shotHitTime=1000000;
-   nextHit=0;
+//   int shotHitTime=1000000;
+   nextHit = nullptr;
 /*   for(h=objectsHitByShip.first();h;h=objectsHitByShip.next())
       if(h->object==HSHOT)
          if(h->hitTime<shotHitTime)
@@ -703,7 +702,7 @@ void Ai::chooseAction()
    else
    {
       int listsize; // used for caching QtList::size()
-      bestShot=0;
+      bestShot = nullptr;
       listsize = myShots.size();
       for (i=0; i<listsize; ++i)
       {
@@ -724,7 +723,7 @@ void Ai::chooseAction()
             shoot=true;
             score=bestScore;
             calculateCollisions = 0;
-            waitShot=(int) rint( random.getDouble() *
+            waitShot=(int) rint( random.bounded(1.0) *
 	                         calcNextShot[Options::aiDifficulty(playerNumber)]
                                  /cfg->gamespeed);
          }
